@@ -132,7 +132,7 @@ def PooledTrainer(base=_NNTrainer, dataset_dir='test', log_dir='net_logs',
                          local_iterations=local_iterations,
                          epochs=epochs,
                          learning_rate=learning_rate,
-                         gous=gpus,
+                         gpus=gpus,
                          pin_memory=pin_memory,
                          load_limit=load_limit,
                          pretrained_path=pretrained_path,
